package Injection;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;

import beans.gmfgraph.accessors;
import beans.gmfgraph.actualFigure;
import beans.gmfgraph.backgroundColor;
import beans.gmfgraph.children;
import beans.gmfgraph.compartments;
import beans.gmfgraph.connections;
import beans.gmfgraph.descriptors;
import beans.gmfgraph.figures;
import beans.gmfgraph.foregroundColor;
import beans.gmfgraph.gmfgraph;
import beans.gmfgraph.labels;
import beans.gmfgraph.layout;
import beans.gmfgraph.location;
import beans.gmfgraph.maximumSize;
import beans.gmfgraph.minimumSize;
import beans.gmfgraph.nodes;
import beans.gmfgraph.preferredSize;
import beans.gmfgraph.size;
import beans.gmfgraph.template;

import com.thoughtworks.xstream.XStream;

public class ParserXML_GMFGraph {

	private static XStream xs;
	private String xml;

	private static gmfgraph pack;
	private static figures figures;

	private ArrayList<descriptors> descriptors;
	private ArrayList<nodes> nodes;
	private ArrayList<connections> connections;
	private ArrayList<compartments> compartments;
	private ArrayList<labels> labels;
	private ArrayList<accessors> childAcessors;

	//private String coreDraws;

	private int ContAux = 0;

	public ParserXML_GMFGraph(){
		xs = new XStream();
		pack = new gmfgraph();

		descriptors = new ArrayList<descriptors>();
		nodes= new ArrayList<nodes>();
		connections = new ArrayList<connections>();
		compartments = new ArrayList<compartments>();
		labels = new ArrayList<labels>();
		childAcessors = new ArrayList<accessors>();

		xs.setMode(XStream.NO_REFERENCES);

		createAlias();
	}

	public void createAlias() {
		//All 
		//Add coleo no classifier
		xs.addImplicitCollection(gmfgraph.class, "nodes");
		xs.addImplicitCollection(gmfgraph.class, "connections");
		xs.addImplicitCollection(gmfgraph.class, "compartments");
		xs.addImplicitCollection(gmfgraph.class, "labels");
		xs.addImplicitCollection(figures.class, "descriptors");
		xs.addImplicitCollection(descriptors.class, "accessors");
		xs.addImplicitCollection(actualFigure.class, "children");
		xs.addImplicitCollection(children.class, "children");
		xs.addImplicitCollection(children.class, "templates");

		//GMFGraph
		xs.alias("gmfgraph:Canvas", gmfgraph.class);
		xs.aliasField("xmi:version", gmfgraph.class, "version");
		xs.aliasField("xmlns:xmi", gmfgraph.class, "xmi");
		xs.aliasField("xmlns:xsi", gmfgraph.class, "xsi");
		xs.aliasField("xmlns:gmfgraph", gmfgraph.class, "xmlsGmfgraph");
		xs.aliasField("name", gmfgraph.class, "name");
		xs.useAttributeFor(gmfgraph.class, "version");
		xs.useAttributeFor(gmfgraph.class, "xmi");
		xs.useAttributeFor(gmfgraph.class, "xsi");
		xs.useAttributeFor(gmfgraph.class, "xmlsGmfgraph");
		xs.useAttributeFor(gmfgraph.class, "name");

		//Figures
		xs.alias("figures", figures.class);
		xs.aliasField("name", figures.class, "name");
		xs.useAttributeFor(figures.class, "name");

		//Descriptors
		xs.alias("descriptors", descriptors.class);
		xs.aliasField("actualFigure", descriptors.class, "actualFigure");
		xs.aliasField("accessors", descriptors.class, "labelAccessor");
		xs.aliasField("accessors", descriptors.class, "accessors");
		xs.useAttributeFor(descriptors.class, "name");

		//actualFigure
		xs.alias("actualFigure", actualFigure.class);
		xs.aliasField("xsi:type", actualFigure.class, "type");
		xs.aliasField("name", actualFigure.class, "name");
		xs.aliasField("lineWidth", actualFigure.class, "lineWidth");
		xs.aliasField("cornerWidth", actualFigure.class, "cornerWidth");
		xs.aliasField("cornerHeight", actualFigure.class, "cornerHeight");
		xs.aliasField("layout", actualFigure.class, "layout");
		xs.aliasField("children", actualFigure.class, "children");
		xs.aliasField("outline", actualFigure.class, "outline");
		xs.aliasField("fill", actualFigure.class, "fill");
		xs.useAttributeFor(actualFigure.class, "type");
		xs.useAttributeFor(actualFigure.class, "name");
		xs.useAttributeFor(actualFigure.class, "lineWidth");
		xs.useAttributeFor(actualFigure.class, "cornerWidth");
		xs.useAttributeFor(actualFigure.class, "cornerHeight");
		xs.useAttributeFor(actualFigure.class, "outline");
		xs.useAttributeFor(actualFigure.class, "fill");

		//layout
		xs.alias("layout", layout.class);
		xs.aliasField("xsi:type", layout.class, "type");
		xs.useAttributeFor(layout.class, "type");

		//template
		xs.alias("template", template.class);
		xs.aliasField("x", template.class, "x");
		xs.aliasField("y", template.class, "y");
		xs.useAttributeFor(template.class, "x");
		xs.useAttributeFor(template.class, "y");

		//location
		xs.alias("location", location.class);
		xs.aliasField("x", location.class, "x");
		xs.aliasField("y", location.class, "y");
		xs.useAttributeFor(location.class, "x");
		xs.useAttributeFor(location.class, "y");

		//size
		xs.alias("size", size.class);
		xs.aliasField("x", size.class, "x");
		xs.aliasField("y", size.class, "y");
		xs.useAttributeFor(size.class, "x");
		xs.useAttributeFor(size.class, "y");

		//maximumSize
		xs.alias("maximumSize", maximumSize.class);
		xs.aliasField("dx", maximumSize.class, "x");
		xs.aliasField("dy", maximumSize.class, "y");
		xs.useAttributeFor(maximumSize.class, "x");
		xs.useAttributeFor(maximumSize.class, "y");

		//minimumSize
		xs.alias("minimumSize", minimumSize.class);
		xs.aliasField("dx", minimumSize.class, "x");
		xs.aliasField("dy", minimumSize.class, "y");
		xs.useAttributeFor(minimumSize.class, "x");
		xs.useAttributeFor(minimumSize.class, "y");

		//preferredSize
		xs.alias("preferredSize", preferredSize.class);
		xs.aliasField("dx", preferredSize.class, "x");
		xs.aliasField("dy", preferredSize.class, "y");
		xs.useAttributeFor(preferredSize.class, "x");
		xs.useAttributeFor(preferredSize.class, "y");

		//foregroundColor
		xs.alias("foregroundColor", foregroundColor.class);
		xs.aliasField("xsi:type", foregroundColor.class, "type");
		xs.aliasField("red", foregroundColor.class, "red");
		xs.aliasField("green", foregroundColor.class, "green");
		xs.aliasField("blue", foregroundColor.class, "blue");
		xs.useAttributeFor(foregroundColor.class, "type");
		xs.useAttributeFor(foregroundColor.class, "red");
		xs.useAttributeFor(foregroundColor.class, "green");
		xs.useAttributeFor(foregroundColor.class, "blue");

		//backgroundColor
		xs.alias("backgroundColor", backgroundColor.class);
		xs.aliasField("xsi:type", backgroundColor.class, "type");
		xs.aliasField("red", backgroundColor.class, "red");
		xs.aliasField("green", backgroundColor.class, "green");
		xs.aliasField("blue", backgroundColor.class, "blue");
		xs.useAttributeFor(backgroundColor.class, "type");
		xs.useAttributeFor(backgroundColor.class, "red");
		xs.useAttributeFor(backgroundColor.class, "green");
		xs.useAttributeFor(backgroundColor.class, "blue");

		//children
		xs.alias("children", children.class);
		xs.aliasField("xsi:type", children.class, "type");
		xs.aliasField("name", children.class, "name");
		xs.aliasField("text", children.class, "text");
		xs.aliasField("outline", children.class, "outline");
		xs.aliasField("fill", children.class, "fill");
		xs.aliasField("lineKind", children.class, "lineKind");
		xs.useAttributeFor(children.class, "type");
		xs.useAttributeFor(children.class, "name");
		xs.useAttributeFor(children.class, "text");
		xs.useAttributeFor(children.class, "outline");
		xs.useAttributeFor(children.class, "fill");
		xs.useAttributeFor(children.class, "lineKind");

		//accessors
		xs.alias("accessors", accessors.class);
		xs.aliasField("accessor", accessors.class, "accessor");
		xs.aliasField("figure", accessors.class, "figure");
		xs.useAttributeFor(accessors.class, "figure");
		xs.useAttributeFor(accessors.class, "accessor");

		//nodes
		xs.alias("nodes", nodes.class);
		xs.aliasField("name", nodes.class, "name");
		xs.aliasField("figure", nodes.class, "figure");
		xs.useAttributeFor(nodes.class, "figure");
		xs.useAttributeFor(nodes.class, "name");

		//connections
		xs.alias("connections", connections.class);
		xs.aliasField("name", connections.class, "name");
		xs.aliasField("figure", connections.class, "figure");
		xs.useAttributeFor(connections.class, "figure");
		xs.useAttributeFor(connections.class, "name");

		//compartments
		xs.alias("compartments", compartments.class);
		xs.aliasField("name", compartments.class, "name");
		xs.aliasField("figure", compartments.class, "figure");
		xs.aliasField("collapsible", compartments.class, "collapsible");
		xs.useAttributeFor(compartments.class, "figure");
		xs.useAttributeFor(compartments.class, "name");
		xs.useAttributeFor(compartments.class, "collapsible");

		//labels
		xs.alias("labels", labels.class);
		xs.aliasField("name", labels.class, "name");
		xs.aliasField("figure", labels.class, "figure");
		xs.aliasField("elementIcon", labels.class, "elementIcon");
		xs.aliasField("accessor", labels.class, "accessor");
		xs.useAttributeFor(labels.class, "figure");
		xs.useAttributeFor(labels.class, "name");
		xs.useAttributeFor(labels.class, "elementIcon");
		xs.useAttributeFor(labels.class, "accessor");

	}

	public figures createFigures(ArrayList<descriptors> descriptors){
		figures = new figures();
		figures.setName("Default");
		figures.setDescriptors(descriptors);
		return figures;
	}

	public descriptors createDescriptorsNode(String name, boolean compartment, String core, String refContainmentFeature){

		ArrayList<children> childset;

		layout newLayout= new layout();
		newLayout.setType("gmfgraph:StackLayout");

		children newChildren = new children();
		newChildren.setType("gmfgraph:Label");
		newChildren.setName(name + "NameFigure");
		newChildren.setText(name);

		actualFigure newActualFigure = new actualFigure();
		newActualFigure.setType("gmfgraph:Rectangle");
		newActualFigure.setName(name + "Figure");
		newActualFigure.setLayout(newLayout);
		childset = new ArrayList<children>();
		childset.add(newChildren);
		newActualFigure.setChildren(childset);

		accessors newAccessors = new accessors();
		newAccessors.setAccessor("getFigure"+ name +"NameFigure");
		newAccessors.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.0");

		descriptors newDescriptors= new descriptors();
		newDescriptors.setName(name + "Figure");
		newDescriptors.setActualFigure(newActualFigure);
		newDescriptors.setLabelAccessor(newAccessors);

		if (core!=null) {
			if (core.equals("Actor") || core.equals("Agent") || core.equals("Role") || core.equals("Position")) {
				drawCompartment(core);
			}else if (core.equals("Goal")) {
				drawGoal();
			}else if (core.equals("Task")) {
				drawTask();
			}else if (core.equals("Resource")) {
				drawResource();
			}else if (core.equals("Softgoal")) {
				drawSoftgoal();
			}
		}else {
			descriptors.add(newDescriptors);
		}

		labels newLabels = new labels();
		newLabels.setName(name + "Name");
		newLabels.setFigure(name + "Figure");
		newLabels.setElementIcon("false");
		newLabels.setAccessor("//@figures.0/@descriptors." + ContAux + "/@accessors.0");
		labels.add(newLabels);

		ContAux += 1;

		nodes newNode = new nodes();
		newNode.setName(name);
		newNode.setFigure(name + "Figure");
		nodes.add(newNode);

		if (compartment) {
			compartments newCompartments = new compartments();
			newCompartments.setName(name + "Compartment");
			newCompartments.setFigure(name + "Figure");
			newCompartments.setCollapsible("true");
			compartments.add(newCompartments);
			newDescriptors.setAccessors(childAcessors);
		} else if(core == null) {
			if(refContainmentFeature.contains("mm") || refContainmentFeature.contains("compartment")) {
				accessors childAccessor = new accessors();
				childAccessor.setAccessor("getFigure"+name+"Figure");
				childAccessor.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure");
				childAcessors.add(childAccessor);	
			}
		}

		return newDescriptors;
	}

	public descriptors createDescriptorsLinkPolyline(String name){

		actualFigure newActualFigure = new actualFigure();
		newActualFigure.setType("gmfgraph:PolylineConnection");
		newActualFigure.setName(name + "Figure");

		descriptors newDescriptors= new descriptors();
		newDescriptors.setName(name + "Figure");
		newDescriptors.setActualFigure(newActualFigure);

		descriptors.add(newDescriptors);

		ContAux += 1;

		connections newConnections = new connections();
		newConnections.setName(name);
		newConnections.setFigure(name + "Figure");

		connections.add(newConnections);

		return newDescriptors;
	}

	//public descriptors createDescriptorsLinkLabel(String name, int index1, int index2){
	public descriptors createDescriptorsLinkLabel(String name){	
		actualFigure newActualFigure = new actualFigure();
		newActualFigure.setType("gmfgraph:Label");
		newActualFigure.setName(name + "Figure");

		descriptors newDescriptors= new descriptors();
		newDescriptors.setName(name + "LabelFigure");
		newDescriptors.setActualFigure(newActualFigure);

		descriptors.add(newDescriptors);

		labels newLabels = new labels();
		newLabels.setName(name + "Name");
		newLabels.setFigure(name + "LabelFigure");
		newLabels.setElementIcon("false");
		//		newLabels.setAccessor("@figures.0/@descriptors." + index1 + "/@accessors." + index2);
		labels.add(newLabels);

		ContAux += 1;

		return newDescriptors;
	}

	public void createXML(){

		//ePackage
		pack.setVersion("2.0");
		pack.setXmi("http://www.omg.org/XMI");
		pack.setXsi("http://www.w3.org/2001/XMLSchema-instance");
		pack.setXmlsGmfgraph("http://www.eclipse.org/gmf/2006/GraphicalDefinition");
		pack.setName("aaa");
		pack.setFigures(figures);

		for (int i = 0; i < nodes.size(); i++) {
			pack.getNodes().add(nodes.get(i));
		}

		for (int i = 0; i < connections.size(); i++) {
			pack.getConnections().add(connections.get(i));
		}

		for (int i = 0; i < compartments.size(); i++) {
			pack.getCompartments().add(compartments.get(i));
		}

		for (int i = 0; i < labels.size(); i++) {
			pack.getLabels().add(labels.get(i));
		}

		xml = xs.toXML(pack);
	}

	private void drawCompartment(String element){

		ArrayList<children> childset = new ArrayList<children>();

		children label = new children("gmfgraph:Label",element+"NameFigure");
		label.setText(element);

		children actorb = new children("gmfgraph:Ellipse", "Actorb");
		actorb.setLineKind("LINE_DASH");
		actorb.setForegroundColor(new foregroundColor());

		accessors accessor1 = new accessors();
		accessor1.setAccessor("getFigure"+element+"NameFigure");

		actualFigure figure = new actualFigure("gmfgraph:Ellipse",element);
		figure.setLayout(new layout("gmfgraph:StackLayout"));
		figure.setForegroundColor(new foregroundColor("254", "254", "254"));

		if(element.equals("Actor") || element.equals("Agent") || element.equals("Role")){

			children actor2 = new children("gmfgraph:Ellipse","Actor2");
			actor2.setLayout(new layout("gmfgraph:StackLayout"));
			actor2.setForegroundColor(new foregroundColor());
			actor2.setSize(new size("70", "70"));
			childset.add(label);
			actor2.setChildren(childset);

			children actor1 = new children("gmfgraph:Rectangle", "Actor1");
			actor1.setOutline("false");
			actor1.setFill("false");
			actor1.setSize(new size("70", "70"));
			childset = new ArrayList<children>();
			childset.add(actor2);
			if(element.equals("Agent")) {
				children line = new children("gmfgraph:Rectangle", "Line");
				line.setForegroundColor(new foregroundColor());
				line.setBackgroundColor(new backgroundColor());
				line.setLocation(new location("5","15"));
				line.setSize(new size("58","1"));
				childset.add(line);
			}else if(element.equals("Role")){
				children line = new children("gmfgraph:Rectangle", "Line");
				line.setForegroundColor(new foregroundColor());
				line.setBackgroundColor(new backgroundColor());
				line.setLocation(new location("7","53"));
				line.setSize(new size("57","1"));
				childset.add(line);
			}
			actor1.setChildren(childset);

			childset = new ArrayList<children>();
			childset.add(actorb);
			childset.add(actor1);

			accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.1/@children.0/@children.0");

		} else {

			children up = new children("gmfgraph:Ellipse", "Up");
			up.setForegroundColor(new foregroundColor());
			up.setLocation(new location("15","0"));
			up.setSize(new size("30","30"));
			childset.add(up);
			children right = new children("gmfgraph:Ellipse", "Right");
			right.setForegroundColor(new foregroundColor());
			right.setLocation(new location("30","15"));
			right.setSize(new size("30","30"));
			childset.add(right);
			children down = new children("gmfgraph:Ellipse", "Down");
			down.setForegroundColor(new foregroundColor());
			down.setLocation(new location("15","30"));
			down.setSize(new size("30","30"));
			childset.add(down);
			children left = new children("gmfgraph:Ellipse", "Left");
			left.setForegroundColor(new foregroundColor());
			left.setLocation(new location("0","15"));
			left.setSize(new size("30","30"));
			childset.add(left);
			children aa = new children("gmfgraph:Rectangle", "aa");
			aa.setOutline("false");
			aa.setLocation(new location("15","15"));
			aa.setSize(new size("30","30"));
			childset.add(aa);

			children position = new children("gmfgraph:Rectangle", element+"2");
			position.setLayout(new layout("gmfgraph:XYLayout"));
			position.setLocation(new location("0","0"));
			position.setSize(new size("60", "60"));
			position.setChildren(childset);

			figure.setType("gmfgraph:Rectangle");
			figure.setMaximumSize(new maximumSize("60","60"));
			figure.setMinimumSize(new minimumSize("60","60"));
			figure.setPreferredSize(new preferredSize("60","60"));

			accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.2");

			childset = new ArrayList<children>();
			childset.add(actorb);
			childset.add(position);
			childset.add(label);
		}

		figure.setChildren(childset);
		descriptors descriptor = new descriptors();
		descriptor.setName(element+"Figure");
		descriptor.setActualFigure(figure);
		descriptor.setLabelAccessor(accessor1);;
		descriptor.setAccessors(childAcessors);
		this.descriptors.add(descriptor);
	}

	private void drawGoal() {

		ArrayList<children> childset = new ArrayList<children>();

		children label = new children("gmfgraph:Label","GoalNameFigure");
		label.setText("Goal");

		actualFigure figure = new actualFigure("gmfgraph:RoundedRectangle","GoalFigure");
		figure.setCornerWidth("60");
		figure.setCornerHeight("60");
		figure.setLayout(new layout("gmfgraph:StackLayout"));
		figure.setForegroundColor(new foregroundColor());
		figure.setPreferredSize(new preferredSize("90","60"));
		childset.add(label);
		figure.setChildren(childset);

		accessors accessor1 = new accessors();
		accessor1.setAccessor("getFigureGoalNameFigure");
		accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.0");

		descriptors descriptor = new descriptors();
		descriptor.setName("GoalFigure");
		descriptor.setActualFigure(figure);
		descriptor.setLabelAccessor(accessor1);;
		this.descriptors.add(descriptor);

		accessors childAccessor = new accessors();
		childAccessor.setAccessor("getFigureGoalFigure");
		childAccessor.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure");
		childAcessors.add(childAccessor);
	}

	private void drawTask() {

		ArrayList<children> childset = new ArrayList<children>();
		ArrayList<template> templates = new ArrayList<template>();

		children label = new children("gmfgraph:Label","TaskNameFigure");
		label.setText("Task");

		children polygon = new children("gmfgraph:Polygon", "Polygon");
		polygon.setForegroundColor(new foregroundColor());
		polygon.setBackgroundColor(new backgroundColor("254","254","254"));
		templates.add(new template("15", "0"));
		templates.add(new template("75", "0"));
		templates.add(new template("90", "30"));
		templates.add(new template("75", "60"));
		templates.add(new template("15", "60"));
		templates.add(new template("0", "30"));
		templates.add(new template("15", "0"));
		polygon.setTemplates(templates);

		actualFigure figure = new actualFigure("gmfgraph:RoundedRectangle","TaskFigure");
		figure.setFill("false");
		figure.setOutline("false");
		figure.setLineWidth("20");
		figure.setCornerWidth("60");
		figure.setCornerHeight("100");
		figure.setPreferredSize(new preferredSize("95","65"));
		figure.setLayout(new layout("gmfgraph:StackLayout"));
		figure.setForegroundColor(new foregroundColor("254","254","254"));
		childset.add(polygon);
		childset.add(label);
		figure.setChildren(childset);

		accessors accessor1 = new accessors();
		accessor1.setAccessor("getFigureTaskNameFigure");
		accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.1");

		descriptors descriptor = new descriptors();
		descriptor.setName("TaskFigure");
		descriptor.setActualFigure(figure);
		descriptor.setLabelAccessor(accessor1);;
		this.descriptors.add(descriptor);

		accessors childAccessor = new accessors();
		childAccessor.setAccessor("getFigureTaskFigure");
		childAccessor.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure");
		childAcessors.add(childAccessor);
	}

	private void drawResource() {

		ArrayList<children> childset = new ArrayList<children>();

		children label = new children("gmfgraph:Label","ResourceNameFigure");
		label.setText("Resource");

		actualFigure figure = new actualFigure("gmfgraph:Rectangle","ResourceFigure");
		figure.setForegroundColor(new foregroundColor());
		figure.setPreferredSize(new preferredSize("75","60"));
		childset.add(label);
		figure.setChildren(childset);

		accessors accessor1 = new accessors();
		accessor1.setAccessor("getFigureResourceNameFigure");
		accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.0");

		descriptors descriptor = new descriptors();
		descriptor.setName("ResourceFigure");
		descriptor.setActualFigure(figure);
		descriptor.setLabelAccessor(accessor1);;
		this.descriptors.add(descriptor);

		accessors childAccessor = new accessors();
		childAccessor.setAccessor("getFigureResourceFigure");
		childAccessor.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure");
		childAcessors.add(childAccessor);
	}

	private void drawSoftgoal() {

		ArrayList<children> childset = new ArrayList<children>();

		children soft1 = new children("gmfgraph:Ellipse","Soft1");
		soft1.setForegroundColor(new foregroundColor());
		soft1.setLocation(new location("0","3"));
		soft1.setSize(new size("60", "54"));

		children soft2 = new children("gmfgraph:Ellipse","Soft2");
		soft2.setForegroundColor(new foregroundColor());
		soft2.setLocation(new location("25","0"));
		soft2.setSize(new size("65", "60"));

		children meio = new children("gmfgraph:Rectangle","Meio");
		meio.setOutline("false");
		meio.setLocation(new location("25","8"));
		meio.setSize(new size("35", "44"));

		children softRetangulo = new children("gmfgraph:Rectangle","SoftRetangulo");
		softRetangulo.setOutline("false");
		softRetangulo.setLayout(new layout("gmfgraph:XYLayout"));
		softRetangulo.setSize(new size("90", "60"));
		childset.add(soft1);
		childset.add(soft2);
		childset.add(meio);
		softRetangulo.setChildren(childset);

		children label = new children("gmfgraph:Label","SoftgoalNameFigure");
		label.setText("Softgoal");

		actualFigure figure = new actualFigure("gmfgraph:Rectangle","SoftgoalFigure");
		figure.setOutline("false");
		figure.setLayout(new layout("gmfgraph:StackLayout"));
		figure.setPreferredSize(new preferredSize("90","60"));
		childset = new  ArrayList<children>();
		childset.add(softRetangulo);
		childset.add(label);
		figure.setChildren(childset);

		accessors accessor1 = new accessors();
		accessor1.setAccessor("getFigureSoftgoalNameFigure");
		accessor1.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure/@children.1");

		descriptors descriptor = new descriptors();
		descriptor.setName("SoftgoalFigure");
		descriptor.setActualFigure(figure);
		descriptor.setLabelAccessor(accessor1);;
		this.descriptors.add(descriptor);

		accessors childAccessor = new accessors();
		childAccessor.setAccessor("getFigureSoftgoalFigure");
		childAccessor.setFigure("//@figures.0/@descriptors." + ContAux + "/@actualFigure");
		childAcessors.add(childAccessor);
	}

	public void createFileGMFGraph(String path, String namefile){
		File file = new File(path + "\\" + namefile + ".gmfgraph");
		try {
			FileWriter fw = new FileWriter(file);
			fw.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>" + "\n");
			fw.write(xml);
			fw.flush();
			fw.close();
			System.out.println("gmfgraph criado");
		} catch (IOException e1) {
			e1.printStackTrace();
		}
	}

	public ArrayList<descriptors> getDescriptors() {
		return descriptors;
	}

	public void setDescriptors(ArrayList<descriptors> descriptors) {
		this.descriptors = descriptors;
	}

	public ArrayList<nodes> getNodes() {
		return nodes;
	}

	public void setNodes(ArrayList<nodes> nodes) {
		this.nodes = nodes;
	}

	/*	public static void main(String[] args) {
		ParserXML_GMFGraph pg = new ParserXML_GMFGraph();

		//		pg.createDescriptorsNode("Teste01", false);
		//		pg.createDescriptorsNode("Teste02", false);
		//		pg.createDescriptorsNode("Teste03", false);
		//		pg.createDescriptorsNode("Teste04", true);
		//		pg.createDescriptorsLinkPolyline("Link01");
		//		pg.createDescriptorsLinkLabel("Link01");
		pg.createDescriptorsLinkPolyline("Link02");
		//		pg.createDescriptorsLinkLabel("Link02");

		pg.createFigures(pg.getDescriptors());
		pg.createXML();
		pg.createFileGMFGraph("D:/Projetos Java/GMF/SR/Teste_iStarPL/model", "testeGMFgraph");
	}*/
}
