package Injection;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;

import javax.tools.Tool;

import beans.gmftool.Gmftool;
import beans.gmftool.Palette;
import beans.gmftool.SmallIcon;
import beans.gmftool.Tools;
import beans.metamodel.details;
import beans.metamodel.eAnnotation;
import beans.metamodel.eClassifier;
import beans.metamodel.eLiteral;
import beans.metamodel.ePackage;
import beans.metamodel.eStructuralFeature;

import com.thoughtworks.xstream.XStream;

public class ParserXML_GMFTool {
	
	private static XStream xs;
	private String xml;
	
	private static Gmftool pack;
	private static Palette palette;
	
	private ArrayList<Tools> creationTools;
	private ArrayList<Tools> toolGroup;
	
	public ParserXML_GMFTool(){
		xs = new XStream();
		pack = new Gmftool();
		
		creationTools = new ArrayList<Tools>();
		toolGroup = new ArrayList<Tools>();
		
		createAlias();
		
	}

	public void createAlias() {
		//All 
		//Add coleo no classifier
		xs.addImplicitCollection(Palette.class, "tools");
		xs.addImplicitCollection(Tools.class, "tools");
		
		//GMFTool
		xs.alias("gmftool:ToolRegistry", Gmftool.class);
		xs.aliasField("xmi:version", Gmftool.class, "version");
		xs.aliasField("xmlns:xmi", Gmftool.class, "xmi");
		xs.aliasField("xmlns:xsi", Gmftool.class, "xsi");
		xs.aliasField("xmlns:gmftool", Gmftool.class, "xmlsGmftool");
		xs.useAttributeFor(Gmftool.class, "version");
		xs.useAttributeFor(Gmftool.class, "xmi");
		xs.useAttributeFor(Gmftool.class, "xsi");
		xs.useAttributeFor(Gmftool.class, "xmlsGmftool");
		
		//Palette
		xs.alias("palette", Palette.class);
		xs.aliasField("title", Palette.class, "title");
		xs.useAttributeFor(Palette.class, "title");
		
		//Tool
		xs.alias("tools", Tools.class);
		xs.aliasField("xsi:type", Tools.class, "type");
		xs.aliasField("title", Tools.class, "title");
		xs.aliasField("collapsible", Tools.class, "collapsible");
		xs.aliasField("description", Tools.class, "description");
		xs.useAttributeFor(Tools.class, "type");
		xs.useAttributeFor(Tools.class, "title");
		xs.useAttributeFor(Tools.class, "collapsible");
		xs.useAttributeFor(Tools.class, "description");
		
		//SmallIcon
		xs.alias("smallIcon", SmallIcon.class);
		xs.aliasField("xsi:type", SmallIcon.class, "type");
		xs.aliasField("path", SmallIcon.class, "path");
		xs.aliasField("bundle", SmallIcon.class, "bundle");
		xs.useAttributeFor(SmallIcon.class, "type");
		xs.useAttributeFor(SmallIcon.class, "path");
		xs.useAttributeFor(SmallIcon.class, "bundle");
		
	}
	
	public Palette createPalette(String title) {
		palette = new Palette();
		palette.setTitle(title + "Palette");
		for (int i = 0; i < toolGroup.size(); i++) {
			palette.getTools().add(toolGroup.get(i));
		}
		return palette;
	}
	
	public Tools createToolGroup(String title){
		Tools newTool = new Tools();
		newTool.setType("gmftool:ToolGroup");
		newTool.setTitle(title);
		newTool.setCollapsible("true");
		
		toolGroup.add(newTool);
		
		return newTool;
	}
	
	public Tools createCreationTool(String title, String toolTitle, SmallIcon si){
		Tools newTool = new Tools();
		newTool.setType("gmftool:CreationTool");
		newTool.setTitle(title);
		newTool.setDescription("Create new " + title);
		newTool.setSmallIcon(si);
		
		boolean toolGroupExist = false;
		
		for (int i = 0; i < toolGroup.size(); i++) {
			if (toolGroup.get(i).getTitle().equals(toolTitle)) {
				toolGroup.get(i).getTools().add(newTool);
				toolGroupExist = true;
			}
		}
		
		if (!toolGroupExist) {
			createToolGroup(toolTitle);
			
			for (int i = 0; i < toolGroup.size(); i++) {
				if (toolGroup.get(i).getTitle().equals(toolTitle)) {
					toolGroup.get(i).getTools().add(newTool);
					toolGroupExist = true;
				}
			}
			
		}
		
		return newTool;
	}
	
	public int getToolGroup(String toolTitle){
		
		int index = 0;
		
		for (int i = 0; i < toolGroup.size(); i++) {
			if (toolGroup.get(i).getTitle().equals(toolTitle)) {
				index = i;
			}
		}
		
		return index;
		
	}
	
//	public Tools createToolGroup(String title){
//		Tools newTool = new Tools();
//		newTool.setType("gmftool:ToolGroup");
//		newTool.setTitle(title);
//		newTool.setCollapsible("true");
//		
//		for (int i = 0; i < creationTools.size(); i++) {
//			newTool.getTools().add(creationTools.get(i));
//		}
//		
//		toolGroup.add(newTool);
//		return newTool;
//	}
	
//	public Tools createCreationTool(String title, SmallIcon si){
//		Tools newTool = new Tools();
//		newTool.setType("gmftool:CreationTool");
//		newTool.setTitle(title);
//		newTool.setDescription("Create new " + title);
//		newTool.setSmallIcon(si);
//		creationTools.add(newTool);
//		return newTool;
//	}
	
	public SmallIcon createSmallIcon(String image, String edit){
		SmallIcon newSmallIcon = new SmallIcon();
		newSmallIcon.setType("gmftool:BundleImage");
		newSmallIcon.setPath("/icons/full/obj16/" + image);
		newSmallIcon.setBundle(edit);
		return newSmallIcon;
	}
	
	public void clearCreationTool(){
		creationTools.removeAll(creationTools);
	}
	
	public void createXML(){
		
		//ePackage
		pack.setVersion("2.0");
		pack.setXmi("http://www.omg.org/XMI");
		pack.setXsi("http://www.w3.org/2001/XMLSchema-instance");
		pack.setXmlsGmftool("http://www.eclipse.org/gmf/2005/ToolDefinition");
		pack.setPalette(palette);
		
		xml = xs.toXML(pack);  
//	    System.out.println(xml);
	}
	
	public void createFileGMFTool(String path, String namefile){
		File file = new File(path + "\\" + namefile + ".gmftool");
		try {
			FileWriter fw = new FileWriter(file);
			fw.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>" + "\n");
			fw.write(xml);
			fw.flush();
			fw.close();
			System.out.println("gmftool criado");
		} catch (IOException e1) {
			e1.printStackTrace();
		}
	}
	
	public ArrayList<Tools> getCreationTools() {
		return creationTools;
	}

	public void setCreationTools(ArrayList<Tools> creationTools) {
		this.creationTools = creationTools;
	}

	public ArrayList<Tools> getToolGroup() {
		return toolGroup;
	}

	public void setToolGroup(ArrayList<Tools> toolGroup) {
		this.toolGroup = toolGroup;
	}

	public static void main(String[] args) {
		ParserXML_GMFTool pg = new ParserXML_GMFTool();
		
		pg.createCreationTool("Teste01", "Actors", pg.createSmallIcon("Imagem01", "cin.ufpe.br.wiki.edit"));
		pg.createCreationTool("Teste02", "Actors", pg.createSmallIcon("Imagem01", "cin.ufpe.br.wiki.edit"));
		pg.createCreationTool("Teste03", "Element", pg.createSmallIcon("Imagem02", "cin.ufpe.br.wiki.edit"));
		pg.createCreationTool("Teste04", "Actors", pg.createSmallIcon("Imagem03", "cin.ufpe.br.wiki.edit"));
//		
//		pg.createToolGroup("Actors");
//		pg.clearCreationTool();
//		
//		pg.createCreationTool("Teste044", pg.createSmallIcon("Imagem01", "cin.ufpe.br.wiki.edit"));
//		pg.createCreationTool("Teste055", pg.createSmallIcon("Imagem02", "cin.ufpe.br.wiki.edit"));
//		pg.createCreationTool("Teste066", pg.createSmallIcon("Imagem03", "cin.ufpe.br.wiki.edit"));
//		
//		pg.createToolGroup("Actors222222");
		
		pg.createPalette("Teste");
		pg.createXML();
		pg.createFileGMFTool("D:/Projetos Java/GMF_GALILEO/ProjetosGMF/Teste_iStarPL/model", "testeGMFtool");
	}
}
